@@ -19,24 +19,13 @@ our @EXPORT_OK = qw(
   dualvar isdual isvstring looks_like_number openhandle readonly set_prototype
   tainted
 );
-our $VERSION    = "1.57";
+our $VERSION    = "1.58";
 $VERSION =~ tr/_//d;
 
 require List::Util; # List::Util loads the XS
 List::Util->VERSION( $VERSION ); # Ensure we got the right XS version (RT#100863)
 
-our @EXPORT_FAIL;
-
-unless (defined &weaken) {
-  push @EXPORT_FAIL, qw(weaken);
-}
-unless (defined &isweak) {
-  push @EXPORT_FAIL, qw(isweak isvstring);
-}
-unless (defined &isvstring) {
-  push @EXPORT_FAIL, qw(isvstring);
-}
-
+# populating @EXPORT_FAIL is done in the XS code
 sub export_fail {
   if (grep { /^isvstring$/ } @_ ) {
     require Carp;
